@@ -1,9 +1,10 @@
 /*
     gwclientstream.cpp - Kopete Groupwise Protocol
   
+    Copyright (c) 2006      Novell, Inc	 	 	 http://www.opensuse.org
     Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
     
-    Based on Iris, Copyright (C) 2003  Justin Karneges
+    Based on Iris, Copyright (C) 2003  Justin Karneges <justin@affinix.com>
     encode_method from Gaim src/protocols/novell/nmconn.c
     Copyright (c) 2004 Novell, Inc. All Rights Reserved
     
@@ -31,10 +32,12 @@
 // #include"protocol.h"
 
 #include <qapplication.h>  // for qdebug
-#include <qguardedptr.h> 
+#include <qpointer.h> 
 #include <qobject.h>
-#include <qptrqueue.h>
+#include <QQueue>
 #include <qtimer.h>
+//Added by qt3to4:
+#include <QByteArray>
 
 #include "bytestream.h"
 #include "connector.h"
@@ -77,7 +80,6 @@ public:
 		tlsHandler = 0;
 		tls = 0;
 //		sasl = 0;
-		in.setAutoDelete(true);
 
 		allowPlain = false;
 		mutualAuth = false;
@@ -106,7 +108,7 @@ public:
 	bool allowPlain, mutualAuth;
 	bool haveLocalAddr;
 	QHostAddress localAddr;
-	Q_UINT16 localPort;
+	quint16 localPort;
 // 	int minimumSSF, maximumSSF;
 // 	QString sasl_mech;
 	bool doBinding;
@@ -137,7 +139,7 @@ public:
 	int errCond;
 	QString errText;
 
-	QPtrQueue<Transfer> in;
+	QQueue<Transfer *> in;
 
 	QTimer noopTimer; // probably not needed
 	int noop_time;
@@ -162,7 +164,7 @@ ClientStream::ClientStream(Connector *conn, TLSHandler *tlsHandler, QObject *par
 
 ClientStream::~ClientStream()
 {
-	reset();
+	reset( true );
 	delete d;
 }
 
@@ -196,7 +198,8 @@ void ClientStream::reset(bool all)
 		d->client.reset();
 	}
 	if(all)
-		d->in.clear();
+		while (!d->in.isEmpty())
+			delete d->in.dequeue();
 }
 
 // Jid ClientStream::jid() const
@@ -295,7 +298,7 @@ void ClientStream::setNoopTime(int mills)
 	d->noopTimer.start(d->noop_time);
 }
 
-void ClientStream::setLocalAddr(const QHostAddress &addr, Q_UINT16 port)
+void ClientStream::setLocalAddr(const QHostAddress &addr, quint16 port)
 {
 	d->haveLocalAddr = true;
 	d->localAddr = addr;
@@ -474,7 +477,7 @@ void ClientStream::cr_connected()
 	d->client.doTLS = d->tlsHandler ? true: false;
 	d->client.doBinding = d->doBinding;*/
 
-	QGuardedPtr<QObject> self = this;
+	QPointer<QObject> self = this;
 	emit connected();
 	if(!self)
 		return;
@@ -519,7 +522,7 @@ void ClientStream::ss_readyRead()
 	a = d->ss->read();
 
 #ifdef LIBGW_DEBUG
-	QCString cs(a.data(), a.size()+1);
+	QByteArray cs(a.data(), a.size()+1);
 	CoreProtocol::debug( QString( "ClientStream: ss_readyRead() recv: %1 bytes" ).arg( a.size() ) );
 	cs_dump( a );
 #endif
@@ -540,7 +543,7 @@ void ClientStream::ss_bytesWritten(int bytes)
 
 void ClientStream::ss_tlsHandshaken()
 {
-	QGuardedPtr<QObject> self = this;
+	QPointer<QObject> self = this;
 	emit securityLayerActivated(LayerTLS);
 	if(!self)
 		return;
@@ -574,7 +577,7 @@ void ClientStream::srvProcessNext()
 
 void ClientStream::doReadyRead()
 {
-	//QGuardedPtr<QObject> self = this;
+	//QPointer<QObject> self = this;
 	emit readyRead();
 	//if(!self)
 	//	return;
