@@ -5,7 +5,7 @@
     Copyright (c) 2002      by Ryan Cumming           <bodnar42@phalynx.dhs.org>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
     Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart at kde.org>
-    Copyright (c) 2005      by Michaël Larouche       <michael.larouche@kdemail.net>
+    Copyright (c) 2005      by Michaël Larouche       <larouche@kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -22,21 +22,26 @@
 #include "msncontact.h"
 
 #include <qcheckbox.h>
+#include <QList>
+#include <QImageReader>
 
 #undef KDE_NO_COMPAT
 #include <kaction.h>
+#include <KActionCollection>
 #include <kdebug.h>
 #include <kfiledialog.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
-#include <krun.h>
-#include <ktempfile.h>
+#include <ktoolinvocation.h>
+#include <ktemporaryfile.h>
 #include <kconfig.h>
 #include <kglobal.h>
 #include <qregexp.h>
 #include <kio/job.h>
+#include <kdialog.h>
+#include <kicon.h>
 
 #include "kopetecontactlist.h"
 #include "kopetechatsessionmanager.h"
@@ -44,8 +49,9 @@
 #include "kopetegroup.h"
 #include "kopeteuiglobal.h"
 #include "kopeteglobal.h"
+#include "kopeteavatarmanager.h"
 
-#include "msninfo.h"
+#include "ui_msninfo.h"
 #include "msnchatsession.h"
 #include "msnnotifysocket.h"
 #include "msnaccount.h"
@@ -58,15 +64,15 @@ MSNContact::MSNContact( Kopete::Account *account, const QString &id, Kopete::Met
 	m_blocked = false;
 	m_reversed = false;
 	m_moving = false;
-	
+
 	m_clientFlags=0;
 
 	setFileCapable( true );
 
-	// When we are not connected, it's because we are loading the contactlist.
+	// When we are not connected, it's because we are loading the contact list.
 	// so we set the initial status to offline.
 	// We set offline directly because modifying the status after is too slow.
-	// (notification, contactlist updating,....)
+	// (notification, contact list updating,....)
 	//
 	// FIXME: Hacks like these shouldn't happen in the protocols, but should be
 	//        covered properly at the libkopete level instead - Martijn
@@ -84,7 +90,7 @@ MSNContact::MSNContact( Kopete::Account *account, const QString &id, Kopete::Met
 
 MSNContact::~MSNContact()
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 }
 
 bool MSNContact::isReachable()
@@ -100,13 +106,13 @@ bool MSNContact::isReachable()
 	// (This is an MSN limitation, not a problem in Kopete)
 	if ( !account()->isConnected() || account()->myself()->onlineStatus() == MSNProtocol::protocol()->HDN )
 		return false;
-		
+
 	//if the contact is offline, it is impossible to send it a message.  but it is impossible
-	//to be sure the contact is realy offline. For example, if the contact is not on the contactlist for
+	//to be sure the contact is really offline. For example, if the contact is not on the contact list for
 	//some reason.
 	if( onlineStatus() == MSNProtocol::protocol()->FLN && ( isAllowed() || isBlocked() ) && !serverGroups().isEmpty() )
 		return false;
-		
+
 	return true;
 }
 
@@ -125,44 +131,58 @@ Kopete::ChatSession *MSNContact::manager( Kopete::Contact::CanCreateFlags canCre
 	return manager;
 }
 
-QPtrList<KAction> *MSNContact::customContextMenuActions()
+QList<KAction*> *MSNContact::customContextMenuActions()
 {
-	QPtrList<KAction> *m_actionCollection = new QPtrList<KAction>;
+	QList<KAction*> *actions = new QList<KAction*>;
 
 	// Block/unblock Contact
 	QString label = isBlocked() ? i18n( "Unblock User" ) : i18n( "Block User" );
 	if( !actionBlock )
 	{
-		actionBlock = new KAction( label, "msn_blocked",0, this, SLOT( slotBlockUser() ),
-			this, "actionBlock" );
+		actionBlock = new KAction( KIcon("msn_blocked"), label, this );
+                //, "actionBlock" );
+		connect( actionBlock, SIGNAL(triggered(bool)), this, SLOT( slotBlockUser()) );
 
 		//show profile
-		actionShowProfile = new KAction( i18n("Show Profile") , 0, this, SLOT( slotShowProfile() ),
-			this, "actionShowProfile" );
+		actionShowProfile = new KAction( i18n("Show Profile"), this );
+                //, "actionShowProfile" );
+		connect( actionShowProfile, SIGNAL(triggered(bool)), this, SLOT(slotShowProfile()) );
 
 		// Send mail (only available if it is an hotmail account)
-		actionSendMail = new KAction( i18n("Send Email...") , "mail_generic",0, this, SLOT( slotSendMail() ),
-			this, "actionSendMail" );
+		actionSendMail = new KAction( KIcon("mail-message-new"), i18n("Send Email..."), this );
+                //, "actionSendMail" );
+		connect( actionSendMail, SIGNAL(triggered(bool)), this, SLOT(slotSendMail()) );
 
 		// Invite to receive webcam
-		actionWebcamReceive = new KAction( i18n( "View Contact's Webcam" ), "webcamreceive",  0, this, SLOT(slotWebcamReceive() ), this, "msnWebcamReceive" ) ;
+		actionWebcamReceive = new KAction( KIcon("webcamreceive"), i18n( "View Contact's Webcam" ), this );
+                //, "msnWebcamReceive" ) ;
+		connect( actionWebcamReceive, SIGNAL(triggered(bool)), this, SLOT(slotWebcamReceive()) );
 
 		//Send webcam action
-		actionWebcamSend = new KAction( i18n( "Send Webcam" ), "webcamsend",  0, this, SLOT(slotWebcamSend() ), this, "msnWebcamSend" ) ;
+		actionWebcamSend = new KAction( KIcon("webcamsend"), i18n( "Send Webcam" ), this );
+                //, "msnWebcamSend" ) ;
+		connect( actionWebcamSend, SIGNAL(triggered(bool)), this, SLOT(slotWebcamSend()) );
 	}
 	else
 		actionBlock->setText( label );
 
 	actionSendMail->setEnabled( static_cast<MSNAccount*>(account())->isHotmail());
 
-	m_actionCollection->append( actionBlock );
-	m_actionCollection->append( actionShowProfile );
-	m_actionCollection->append( actionSendMail );
-	m_actionCollection->append( actionWebcamReceive );
-	m_actionCollection->append( actionWebcamSend );
+	actions->append( actionBlock );
+	actions->append( actionShowProfile );
+	actions->append( actionSendMail );
+	actions->append( actionWebcamReceive );
+	actions->append( actionWebcamSend );
 
+	// temporary action collection, used to apply Kiosk policy to the actions
+	KActionCollection tempCollection((QObject*)0);
+	tempCollection.addAction(QLatin1String("contactBlock"), actionBlock);
+	tempCollection.addAction(QLatin1String("contactViewProfile"), actionShowProfile);
+	tempCollection.addAction(QLatin1String("contactMail"), actionSendMail);
+	tempCollection.addAction(QLatin1String("contactInviteToViewWebcam"), actionWebcamSend);
+	tempCollection.addAction(QLatin1String("contactViewWebcam"), actionWebcamReceive);
 
-	return m_actionCollection;
+	return actions;
 }
 
 void MSNContact::slotBlockUser()
@@ -171,41 +191,45 @@ void MSNContact::slotBlockUser()
 	if( !notify )
 	{
 		KMessageBox::error( Kopete::UI::Global::mainWidget(),
-			i18n( "<qt>Please go online to block or unblock a contact.</qt>" ),
+			i18n( "<qt>You need to go online to block or unblock a contact.</qt>" ),
 			i18n( "MSN Plugin" ));
 		return;
 	}
 
 	if( m_blocked )
 	{
-		notify->removeContact( contactId(), MSNProtocol::BL, QString::null, QString::null );
+		notify->removeContact( contactId(), MSNProtocol::BL, QString(), QString() );
 	}
 	else
 	{
 		if(m_allowed)
-			notify->removeContact( contactId(), MSNProtocol::AL, QString::null, QString::null );
+			notify->removeContact( contactId(), MSNProtocol::AL, QString(), QString() );
 		else
-			notify->addContact( contactId(), MSNProtocol::BL, QString::null, QString::null, QString::null );
+			notify->addContact( contactId(), MSNProtocol::BL, QString(), QString(), QString() );
 	}
 }
 
 void MSNContact::slotUserInfo()
 {
-	KDialogBase *infoDialog=new KDialogBase( 0l, "infoDialog", /*modal = */false, QString::null, KDialogBase::Close , KDialogBase::Close, false );
+	KDialog *infoDialog=new KDialog;
+	infoDialog->setButtons( KDialog::Close );
+	infoDialog->setDefaultButton( KDialog::Close );
 	QString nick=property( Kopete::Global::Properties::self()->nickName()).value().toString();
-	QString personalMessage=property( MSNProtocol::protocol()->propPersonalMessage).value().toString();
-	MSNInfo *info=new MSNInfo ( infoDialog,"info");
-	info->m_id->setText( contactId() );
-	info->m_displayName->setText(nick);
-	info->m_personalMessage->setText(personalMessage);
-	info->m_phh->setText(m_phoneHome);
-	info->m_phw->setText(m_phoneWork);
-	info->m_phm->setText(m_phoneMobile);
-	info->m_reversed->setChecked(m_reversed);
+	QString personalMessage=statusMessage().message();
+	QWidget* w=new QWidget( infoDialog );
+	Ui::MSNInfo info;
+	info.setupUi( w );
+	info.m_id->setText( contactId() );
+	info.m_displayName->setText(nick);
+	info.m_personalMessage->setText(personalMessage);
+	info.m_phh->setText(m_phoneHome);
+	info.m_phw->setText(m_phoneWork);
+	info.m_phm->setText(m_phoneMobile);
+	info.m_reversed->setChecked(m_reversed);
 
-	connect( info->m_reversed, SIGNAL(toggled(bool)) , this, SLOT(slotUserInfoDialogReversedToggled()));
+	connect( info.m_reversed, SIGNAL(toggled(bool)) , this, SLOT(slotUserInfoDialogReversedToggled()));
 
-	infoDialog->setMainWidget(info);
+	infoDialog->setMainWidget(w);
 	infoDialog->setCaption(nick);
 	infoDialog->show();
 }
@@ -220,7 +244,7 @@ void MSNContact::slotUserInfoDialogReversedToggled()
 
 void MSNContact::deleteContact()
 {
-	kdDebug( 14140 ) << k_funcinfo << endl;
+	kDebug( 14140 ) ;
 
 	MSNNotifySocket *notify = static_cast<MSNAccount*>( account() )->notifySocket();
 	if( notify )
@@ -230,18 +254,18 @@ void MSNContact::deleteContact()
 			// Remove from all groups he belongs (if applicable)
 			for( QMap<QString, Kopete::Group*>::Iterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
 			{
-				kdDebug(14140) << k_funcinfo << "Removing contact from group \"" << it.key() << "\"" << endl;
+				kDebug(14140) << "Removing contact from group \"" << it.key() << "\"";
 				notify->removeContact( contactId(), MSNProtocol::FL, guid(), it.key() );
 			}
-	
-			// Then trully remove it from server contact list, 
-			// because only removing the contact from his groups isn't sufficent from MSNP11.
-			kdDebug( 14140 ) << k_funcinfo << "Removing contact from top-level." << endl;
-			notify->removeContact( contactId(), MSNProtocol::FL, guid(), QString::null);
+
+			// Then trully remove it from server contact list,
+			// because only removing the contact from his groups isn't sufficient from MSNP11.
+			kDebug( 14140 ) << "Removing contact from top-level.";
+			notify->removeContact( contactId(), MSNProtocol::FL, guid(), QString());
 		}
 		else
 		{
-			kdDebug( 14140 ) << k_funcinfo << "The contact is already removed from server, just delete it" << endl;
+			kDebug( 14140 ) << "The contact is already removed from server, just delete it";
 			deleteLater();
 		}
 	}
@@ -249,7 +273,7 @@ void MSNContact::deleteContact()
 	{
 		// FIXME: This case should be handled by Kopete, not by the plugins :( - Martijn
 		// FIXME: We should be able to delete contacts offline, and remove it from server next time we go online - Olivier
-		KMessageBox::error( Kopete::UI::Global::mainWidget(), i18n( "<qt>Please go online to remove a contact from your contact list.</qt>" ), i18n( "MSN Plugin" ));
+		KMessageBox::error( Kopete::UI::Global::mainWidget(), i18n( "<qt>You need to go online to remove a contact from your contact list.</qt>" ), i18n( "MSN Plugin" ));
 	}
 }
 
@@ -307,7 +331,7 @@ uint MSNContact::clientFlags() const
 
 void MSNContact::setClientFlags( uint flags )
 {
-	if(m_clientFlags != flags) 
+	if(m_clientFlags != flags)
 	{
 		if(hasProperty( MSNProtocol::protocol()->propClient.key() ))
 		{
@@ -349,7 +373,7 @@ void MSNContact::setInfo(const  QString &type,const QString &data )
 		else if( data == "N" )
 			m_phone_mob = false;
 		else
-			kdDebug( 14140 ) << k_funcinfo << "Unknown MOB " << data << endl;
+			kDebug( 14140 ) << "Unknown MOB " << data;
 	}
 	else if( type == "MFN" )
 	{
@@ -357,7 +381,7 @@ void MSNContact::setInfo(const  QString &type,const QString &data )
 	}
 	else
 	{
-		kdDebug( 14140 ) << k_funcinfo << "Unknow info " << type << " " << data << endl;
+		kDebug( 14140 ) << "Unknow info " << type << ' ' << data;
 	}
 }
 
@@ -366,24 +390,21 @@ void MSNContact::serialize( QMap<QString, QString> &serializedData, QMap<QString
 {
 	// Contact id and display name are already set for us, only add the rest
 	QString groups;
-	bool firstEntry = true;
 	for( QMap<QString, Kopete::Group *>::ConstIterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
 	{
-		if( !firstEntry )
-		{
-			groups += ",";
-			firstEntry = true;
-		}
 		groups += it.key();
+		groups += ',';
 	}
+    if(groups.length() > 0)
+        groups.truncate(groups.length()-1);
 
 	QString lists="C";
 	if(m_blocked)
-		lists +="B";
+		lists +='B';
 	if(m_allowed)
-		lists +="A";
+		lists +='A';
 	if(m_reversed)
-		lists +="R";
+		lists +='R';
 
 	serializedData[ "groups" ]  = groups;
 	serializedData[ "PHH" ]  = m_phoneHome;
@@ -406,7 +427,7 @@ const QMap<QString, Kopete::Group*>  MSNContact::serverGroups() const
 {
 	return m_serverGroups;
 }
-void MSNContact::clearServerGroups() 
+void MSNContact::clearServerGroups()
 {
 	m_serverGroups.clear();
 }
@@ -426,23 +447,23 @@ void MSNContact::sync( unsigned int changed )
 		// because m_serverGroups will be only updated with the reply of the server
 		// and then, the same command can be sent twice.
 		// FIXME: if this method is called a seconds times, that mean change can be
-		//        done in the contactlist. we should found a way to recall this
+		//        done in the contact list. we should found a way to recall this
 		//        method later. (a QTimer?)
-		kdDebug( 14140 ) << k_funcinfo << " This contact is already moving. Abort sync    id: " << contactId() << endl;
+		kDebug( 14140 ) << " This contact is already moving. Abort sync    id: " << contactId();
 		return;
 	}
-	
+
 	MSNNotifySocket *notify = static_cast<MSNAccount*>( account() )->notifySocket();
 	if( !notify )
 	{
 		//We are not connected, we will doing it next connection.
-		//Force to reload the whole contactlist from server to suync groups when connecting
+		//Force to reload the whole contact list from server to suync groups when connecting
 		account()->configGroup()->writeEntry("serial", 0 );
 		return;
 	}
-	
+
 	if(m_deleted)  //the contact hasn't been synced from server yet.
-		return; 
+		return;
 
 	unsigned int count=m_serverGroups.count();
 
@@ -451,22 +472,23 @@ void MSNContact::sync( unsigned int changed )
 		return;
 
 	//STEP ONE : add the contact to every kopetegroups where the MC is
-	QPtrList<Kopete::Group> groupList = metaContact()->groups();
-	for ( Kopete::Group *group = groupList.first(); group; group = groupList.next() )
+	QList<Kopete::Group*> groupList = metaContact()->groups();
+	Kopete::Group *group;
+	foreach( group, groupList )
 	{
 		//For each group, ensure it is on the MSN server
 		if( !group->pluginData( protocol() , account()->accountId() + " id" ).isEmpty() )
 		{
 			QString Gid=group->pluginData( protocol(), account()->accountId() + " id" );
-			if( !static_cast<MSNAccount*>( account() )->m_groupList.contains(Gid) ) 
-			{ // ohoh!   something is corrupted on the contactlist.xml
+			if( !static_cast<MSNAccount*>( account() )->m_groupList.contains(Gid) )
+			{ // ohoh!   something is corrupted on the contact list.xml
 			  // anyway, we never should add a contact to an unexisting group on the server.
 			  //     This shouln't be possible anymore  2004-06-10 -Olivier
 
 				//repair the problem
-				group->setPluginData( protocol() , account()->accountId() + " id" , QString::null);
-				group->setPluginData( protocol() , account()->accountId() + " displayName" , QString::null);
-				kdWarning( 14140 ) << k_funcinfo << " Group " << group->displayName() << " marked with id #" <<Gid << " does not seems to be anymore on the server" << endl;
+				group->setPluginData( protocol() , account()->accountId() + " id" , QString());
+				group->setPluginData( protocol() , account()->accountId() + " displayName" , QString());
+				kWarning( 14140 ) << " Group " << group->displayName() << " marked with id #" <<Gid << " does not seems to be anymore on the server";
 
 				if(!group->displayName().isEmpty() && group->type() == Kopete::Group::Normal) //not the top-level
 				{
@@ -479,7 +501,7 @@ void MSNContact::sync( unsigned int changed )
 			else if( !m_serverGroups.contains(Gid) )
 			{
 				//Add the contact to the group on the server
-				notify->addContact( contactId(), MSNProtocol::FL, QString::null, guid(), Gid );
+				notify->addContact( contactId(), MSNProtocol::FL, QString(), guid(), Gid );
 				count++;
 				m_moving=true;
 			}
@@ -502,12 +524,12 @@ void MSNContact::sync( unsigned int changed )
 	//STEP TWO : remove the contact from groups where the MC is not, but let it at least in one group
 
 	//contact is not in that group. on the server. we will remove them dirrectly after the loop
-	QValueList<QString> removinglist; 
-	
+	QStringList removinglist;
+
 	for( QMap<QString, Kopete::Group*>::Iterator it = m_serverGroups.begin();(count > 1 && it != m_serverGroups.end()); ++it )
 	{
 		if( !static_cast<MSNAccount*>( account() )->m_groupList.contains(it.key()) )
-		{ // ohoh!   something is corrupted on the contactlist.xml
+		{ // ohoh!   something is corrupted on the contact list.xml
 		  // anyway, we never should add a contact to an unexisting group on the server.
 
 			//repair the problem ...     //contactRemovedFromGroup( it.key() );
@@ -515,12 +537,12 @@ void MSNContact::sync( unsigned int changed )
 			removinglist.append(it.key());
 			count--;
 
-			kdDebug( 14140 ) << k_funcinfo << "the group marked with id #" << it.key() << " does not seems to be anymore on the server" << endl;
+			kDebug( 14140 ) << "the group marked with id #" << it.key() << " does not seems to be anymore on the server";
 
 			continue;
 		}
 
-		Kopete::Group *group=it.data();
+		Kopete::Group *group=it.value();
 		if(!group) //we can't trust the data of it()   see in MSNProtocol::deserializeContact why
 			group=static_cast<MSNAccount*>( account() )->m_groupList[it.key()];
 		if( !metaContact()->groups().contains(group) )
@@ -530,8 +552,8 @@ void MSNContact::sync( unsigned int changed )
 			count--;
 		}
 	}
-	
-	for(QValueList<QString>::Iterator it= removinglist.begin() ; it != removinglist.end() ; ++it )
+
+	for(QStringList::Iterator it= removinglist.begin() ; it != removinglist.end() ; ++it )
 		contactRemovedFromGroup(*it);
 
 	//FINAL TEST: is the contact at least in a group..
@@ -539,7 +561,7 @@ void MSNContact::sync( unsigned int changed )
 	//   we add the contact to the group #0 (the default one)
 	/*if(count==0)
 	{
-//		notify->addContact( contactId(), MSNProtocol::FL, QString::null, guid(), "0");
+//		notify->addContact( contactId(), MSNProtocol::FL, QString(), guid(), "0");
 	}*/
 }
 
@@ -562,7 +584,7 @@ void MSNContact::contactRemovedFromGroup( const QString& groupId )
 
 void MSNContact::rename( const QString &newName )
 {
-	//kdDebug( 14140 ) << k_funcinfo << "From: " << displayName() << ", to: " << newName << endl;
+	//kDebug( 14140 ) << "From: " << displayName() << ", to: " << newName;
 
 /*	if( newName == displayName() )
 		return;*/
@@ -577,28 +599,28 @@ void MSNContact::rename( const QString &newName )
 
 void MSNContact::slotShowProfile()
 {
-	KRun::runURL( KURL( QString::fromLatin1("http://members.msn.com/?pgmarket=it-it&mem=") + contactId())  , "text/html" );
+	KToolInvocation::invokeBrowser( QString::fromLatin1("http://members.msn.com/default.msnw?mem=") + contactId()) ;
 }
 
 
 /**
  * FIXME: Make this a standard KMM API call
  */
-void MSNContact::sendFile( const KURL &sourceURL, const QString &altFileName, uint /*fileSize*/ )
+void MSNContact::sendFile( const KUrl &sourceURL, const QString &altFileName, uint /*fileSize*/ )
 {
 	QString filePath;
 
 	//If the file location is null, then get it from a file open dialog
 	if( !sourceURL.isValid() )
-		filePath = KFileDialog::getOpenFileName( QString::null ,"*", 0l  , i18n( "Kopete File Transfer" ));
+		filePath = KFileDialog::getOpenFileName( KUrl(), "*", 0l  , i18n( "Kopete File Transfer" ));
 	else
-		filePath = sourceURL.path(-1);
+		filePath = sourceURL.path(KUrl::RemoveTrailingSlash);
 
-	//kdDebug(14140) << "MSNContact::sendFile: File chosen to send:" << fileName << endl;
+	//kDebug(14140) << "MSNContact::sendFile: File chosen to send:" << fileName;
 
 	if ( !filePath.isEmpty() )
 	{
-		Q_UINT32 fileSize = QFileInfo(filePath).size();
+		quint32 fileSize = QFileInfo(filePath).size();
 		//Send the file
 		static_cast<MSNChatSession*>( manager(Kopete::Contact::CanCreate) )->sendFile( filePath, altFileName, fileSize );
 
@@ -615,7 +637,7 @@ void MSNContact::setOnlineStatus(const Kopete::OnlineStatus& status)
 				protocol() ,
 				status.internalStatus()+15 ,
 				status.overlayIcons() + QStringList("msn_blocked") ,
-				i18n("%1|Blocked").arg( status.description() ) ) );
+				i18n("%1|Blocked", status.description() ) ) );
 	}
 	else if(!isBlocked() && status.internalStatus() >= 15)
 	{	//the user is not blocked, but the status is blocked
@@ -667,26 +689,29 @@ void MSNContact::slotSendMail()
 	}
 }
 
-void MSNContact::setDisplayPicture(KTempFile *f)
+void MSNContact::setDisplayPicture(KTemporaryFile *f)
 {
 	//copy the temp file somewere else.
 	// in a better world, the file could be dirrectly wrote at the correct location.
 	// but the custom emoticon code is to deeply merged in the display picture code while it could be separated.
-	QString newlocation=locateLocal( "appdata", "msnpictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
+	Kopete::AvatarManager::AvatarEntry entry;
+	entry.name = contactId();
+	entry.category = Kopete::AvatarManager::Contact;
+	entry.contact = this;
 
-	KIO::Job *j=KIO::file_move( KURL::fromPathOrURL( f->name() ) , KURL::fromPathOrURL( newlocation ) , -1, true /*overwrite*/ , false /*resume*/ , false /*showProgressInfo*/ );
-	
-	f->setAutoDelete(false);
+	f->open();
+	entry.image = QImageReader(f).read();
+	f->close();
+
+	entry = Kopete::AvatarManager::self()->add(entry);
+
+	f->setAutoRemove(true);
 	delete f;
 
-	//let the time to KIO to copy the file
-	connect(j, SIGNAL(result(KIO::Job *)) , this, SLOT(slotEmitDisplayPictureChanged() ));
-}
+	if (entry.path.isNull())
+		return;
 
-void MSNContact::slotEmitDisplayPictureChanged()
-{
-	QString newlocation=locateLocal( "appdata", "msnpictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
-	setProperty( Kopete::Global::Properties::self()->photo() , newlocation );
+	setProperty( Kopete::Global::Properties::self()->photo() , entry.path );
 	emit displayPictureChanged();
 }
 
@@ -700,9 +725,8 @@ void MSNContact::setObject(const QString &obj)
 	removeProperty( Kopete::Global::Properties::self()->photo()  ) ;
 	emit displayPictureChanged();
 
-	KConfig *config = KGlobal::config();
-	config->setGroup( "MSN" );
-	if ( config->readNumEntry( "DownloadPicture", 2 ) >= 2 && !obj.isEmpty() 
+    KConfigGroup *config=account()->configGroup();
+	if ( config->readEntry( "DownloadPicture", 2 ) >= 2 && !obj.isEmpty()
 			 && account()->myself()->onlineStatus().status() != Kopete::OnlineStatus::Invisible )
 		manager(Kopete::Contact::CanCreate); //create the manager which will download the photo automatically.
 }
