@@ -23,14 +23,15 @@
 #include "msnsocket.h"
 //#include "msnprotocol.h"
 
-#include <qregexp.h>
-#include <qtimer.h>
+#include <QRegExp>
+#include <QTimer>
+#include <QByteArray>
 
 #include <kdebug.h>
 #include <kconfig.h>
-#include <kbufferedsocket.h>
-#include <kserversocket.h>
-#include <kresolver.h>
+#include <k3bufferedsocket.h>
+#include <k3serversocket.h>
+#include <k3resolver.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kurl.h>
@@ -47,7 +48,7 @@ class MimeMessage
 		QString getValue(const QString &key)
 		{
 			QRegExp rx(key+": ([^\r\n]+)");
-			rx.search(message);
+			rx.indexIn(message);
 			return rx.cap(1);
 		}
 	private:
@@ -77,7 +78,7 @@ void MSNSocket::connect( const QString &server, uint port )
 {
 	if ( m_onlineStatus == Connected || m_onlineStatus == Connecting )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "Already connected or connecting! Not connecting again." << endl;
+		kWarning( 14140 ) << "Already connected or connecting! Not connecting again.";
 		return;
 	}
 
@@ -85,7 +86,7 @@ void MSNSocket::connect( const QString &server, uint port )
 	{
 		// Cleanup first.
 		// FIXME: More generic!!!
-		kdWarning( 14140 ) << k_funcinfo << "We're still disconnecting! Deleting socket the hard way first." << endl;
+		kWarning( 14140 ) << "We're still disconnecting! Deleting socket the hard way first.";
 		delete m_socket;
 	}
 
@@ -115,7 +116,7 @@ void MSNSocket::connect( const QString &server, uint port )
 	QObject::connect( m_socket, SIGNAL( readyRead() ),             this, SLOT( slotDataReceived() ) );
 	QObject::connect( m_socket, SIGNAL( readyWrite() ),            this, SLOT( slotReadyWrite() ) );
 	QObject::connect( m_socket, SIGNAL( hostFound() ),	       this, SLOT( slotHostFound() ) );
-	QObject::connect( m_socket, SIGNAL( connected( const KResolverEntry&) ), this, SLOT( slotConnectionSuccess() ) );
+	QObject::connect( m_socket, SIGNAL( connected( const KNetwork::KResolverEntry &) ), this, SLOT( slotConnectionSuccess() ) );
 	QObject::connect( m_socket, SIGNAL( gotError( int ) ),         this, SLOT( slotSocketError( int ) ) );
 	QObject::connect( m_socket, SIGNAL( closed( ) ),               this, SLOT( slotSocketClosed( ) ) );
 
@@ -123,7 +124,8 @@ void MSNSocket::connect( const QString &server, uint port )
 	{
 		if(m_timer == 0L)
 		{
-			m_timer = new QTimer(this, "Http poll timer");
+			m_timer = new QTimer(this);
+			m_timer->setObjectName( QLatin1String("Http poll timer") ) ;
 			// Connect the slot HttpPoll with the timer timeout signal.
 			QObject::connect(m_timer, SIGNAL(timeout()), this, SLOT(slotHttpPoll()));
 		}
@@ -175,7 +177,7 @@ void MSNSocket::setOnlineStatus( MSNSocket::OnlineStatus status )
 
 void MSNSocket::slotSocketError( int error )
 {
-	kdWarning( 14140 ) << k_funcinfo << "Error: " << error << " (" << m_socket->errorString() << ")" << endl;
+	kWarning( 14140 ) << "Error: " << error << " (" << m_socket->errorString() << ')';
 
 	if(!KSocketBase::isFatalError(error))
 		return;
@@ -183,7 +185,7 @@ void MSNSocket::slotSocketError( int error )
 
 	QString errormsg = i18n( "There was an error while connecting to the MSN server.\nError message:\n" );
 	if ( error == KSocketBase::LookupFailure )
-		errormsg += i18n( "Unable to lookup %1" ).arg( m_socket->peerResolver().nodeName() );
+		errormsg += i18n( "Unable to lookup %1", m_socket->peerResolver().nodeName() );
 	else
 		errormsg +=  m_socket->errorString() ;
 
@@ -196,7 +198,8 @@ void MSNSocket::slotSocketError( int error )
 	//like if the socket is closed
 	emit socketClosed();
 
-	emit errorMessage( ErrorConnectionError, errormsg );
+	//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, errormsg, i18n( "MSN Plugin" ) );
+	emit errorMessage( ErrorNormal, errormsg );
 }
 
 void MSNSocket::slotDataReceived()
@@ -205,24 +208,24 @@ void MSNSocket::slotDataReceived()
 	if ( avail < 0 )
 	{
 		// error!
-		kdWarning( 14140 ) << k_funcinfo << "bytesAvailable() returned " << avail
+		kWarning( 14140 ) << "bytesAvailable() returned " << avail
 		 	<< ". This should not happen!" << endl
-			<< "Are we disconnected? Backtrace:" << endl << kdBacktrace() << endl;
+			<< "Are we disconnected? Backtrace:" << endl << kBacktrace() << endl;
 		return;
 	}
 
 	// incoming data, plus an extra char where we pretend a NUL is so the conversion
 	// to QCString doesn't go over the end of the allocated memory.
-	char *buffer = new char[ avail + 1 ];
-	int ret = m_socket->readBlock( buffer, avail );
+	QByteArray buffer(avail, '\0');
+	int ret = m_socket->read( buffer.data(), avail );
 
 	if ( ret < 0 )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "readBlock() returned " << ret << "!" <<endl;
+		kWarning( 14140 ) << "read() returned " << ret << '!';
 	}
 	else if ( ret == 0 )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "readBlock() returned no data!" <<endl;
+		kWarning( 14140 ) << "read() returned no data!";
 	}
 	else
 	{
@@ -230,13 +233,13 @@ void MSNSocket::slotDataReceived()
 		{
 			if ( ret != avail)
 			{
-				kdWarning( 14140 ) << k_funcinfo << avail << " bytes were reported available, "
-					<< "but readBlock() returned only " << ret << " bytes! Proceeding anyway." << endl;
+				kWarning( 14140 ) << avail << " bytes were reported available, "
+					<< "but read() returned only " << ret << " bytes! Proceeding anyway." << endl;
 			}
 		}
 		else
 		{
-			kdDebug( 14140 ) << k_funcinfo << "Read " << ret << " bytes into 4kb block." << endl;
+			kDebug( 14140 ) << "Read " << ret << " bytes into 4kb block.";
 		}
 
 
@@ -248,18 +251,18 @@ void MSNSocket::slotDataReceived()
 			QByteArray bytes;
 
 			// Check if all data has arrived.
-			rawData = QString(QCString(buffer, avail + 1));
-			bool headers = (rawData.find(QRegExp("HTTP/\\d\\.\\d (\\d+) ([^\r\n]+)")) != -1);
+			rawData = QString(buffer);
+			bool headers = (rawData.indexOf(QRegExp("HTTP/\\d\\.\\d (\\d+) ([^\r\n]+)")) != -1);
 
 			if(headers)
 			{
 				// The http header packet arrived.
-				int endOfHeaders = rawData.find("\r\n\r\n");
+				int endOfHeaders = rawData.indexOf("\r\n\r\n");
 				if((endOfHeaders + 4) == avail)
 				{
 					// Only the response headers data is included.
 					QRegExp re("Content-Length: ([^\r\n]+)");
-					if(re.search(rawData) != -1)
+					if(re.indexIn(rawData) != -1)
 					{
 						bool valid;
 						int l = re.cap(1).toInt(&valid);
@@ -267,9 +270,8 @@ void MSNSocket::slotDataReceived()
 						{
 							// The packet contains the headers but does not contain the content data;
 							// buffer the data received and read again.
-							m_buffer.add(buffer, avail);
+							m_buffer.append(buffer);
 
-							delete[] buffer;
 							// Update how much data remains.
 							m_remaining = l;
 							return;
@@ -280,13 +282,12 @@ void MSNSocket::slotDataReceived()
 			else
 			{
 				// Write the received data to the buffer.
-				m_buffer.add(buffer, avail);
+				m_buffer.append(buffer);
 
 				m_remaining -= avail;
 				if(m_remaining != 0)
 				{
 					// We have not received all the content data, read again.
-					delete[] buffer;
 					return;
 				}
 
@@ -297,7 +298,7 @@ void MSNSocket::slotDataReceived()
 			if(bytes.size() == 0) 
 			{
 				// The response headers and the content came in one packet.
-				bytes.assign(buffer, avail);
+				bytes = buffer;
 			}
 
 
@@ -314,29 +315,29 @@ void MSNSocket::slotDataReceived()
 				// Retrieve the X-MSN-Messenger header.
 				QString header = response.getHeaders()->getValue("X-MSN-Messenger");
 
-				QStringList parts = QStringList::split(";", header.replace(" ", ""));
+				QStringList parts = header.replace(' ', "").split( ';', QString::SkipEmptyParts );
 				if(!header.isNull() && (parts.count() >= 2))
 				{
-					if(parts[0].find("SessionID", 0) != -1)
+					if(parts[0].indexOf("SessionID", 0) != -1)
 					{
 						// Assign the session id.
-						m_sessionId = parts[0].section("=", 1, 1);
+						m_sessionId = parts[0].section('=', 1, 1);
 					}else
 						error = true;
 
-					if(parts[1].find("GW-IP", 0) != -1)
+					if(parts[1].indexOf("GW-IP", 0) != -1)
 					{
 						// Assign the gateway IP address.
-						m_gwip = parts[1].section("=", 1, 1);
+						m_gwip = parts[1].section('=', 1, 1);
 					}else
 						error = true;
 
 
 					if(parts.count() > 2)
-						if((parts[2].find("Session", 0) != -1) && (parts[2].section("=", 1, 1) == "close"))
+						if((parts[2].indexOf("Session", 0) != -1) && (parts[2].section('=', 1, 1) == "close"))
 						{
 							// The http session has been closed by the server, disconnect.
-							kdDebug(14140) << k_funcinfo << "Session closed." << endl;
+							kDebug(14140) << "Session closed.";
 							m_bCanPoll = false;
 							disconnect();
 							return;
@@ -362,9 +363,9 @@ void MSNSocket::slotDataReceived()
 					{
 						// Otherwise, if the content length is greater than zero, get the web response stream.
 						QDataStream *stream = response.getResponseStream();
-						buffer = new char[length];
+						buffer.fill('\0', length);
 						// Read the web response content.
-						stream->readRawBytes(buffer, length);
+						stream->readRawData(buffer.data(), length);
 						ret = length;
 					}else
 						error = true;
@@ -375,7 +376,7 @@ void MSNSocket::slotDataReceived()
 
 			if(error)
 			{
-				kdDebug(14140) << k_funcinfo << "Http error: " << response.getStatusCode() << " "
+				kDebug(14140) << "Http error: " << response.getStatusCode() << ' '
 					<< response.getStatusDescription() << endl;
 
 				// If we encountered an error, disconnect and return.
@@ -386,11 +387,11 @@ void MSNSocket::slotDataReceived()
 			}
 		}
 
-		// Simple check to avoid dumping the binary data from the icons and emoticons to kdDebug:
+		// Simple check to avoid dumping the binary data from the icons and emoticons to kDebug:
 		// all MSN commands start with one or more uppercase characters.
 		// For now just check the first three chars, let's see how accurate it is.
 		// Additionally, if we receive an MSN-P2P packet, strip off anything after the P2P header.
-		rawData = QString( QCString( buffer, ((!m_useHttp)? avail : ret) + 1 ) ).stripWhiteSpace().replace(
+		rawData = QString( QByteArray( buffer, ((!m_useHttp)? avail : ret) + 1 ) ).trimmed().replace(
 			QRegExp( "(P2P-Dest:.[a-zA-Z@.]*).*" ), "\\1\n\n(Stripped binary data)" );
 
 		bool isBinary = false;
@@ -401,12 +402,12 @@ void MSNSocket::slotDataReceived()
 		}
 
 		if ( isBinary )
-			kdDebug( 14141 ) << k_funcinfo << "(Stripped binary data)" << endl;
+			kDebug( 14141 ) << "(Stripped binary data)";
 		else
-			kdDebug( 14141 ) << k_funcinfo << rawData << endl;
+			kDebug( 14141 ) << rawData;
 
 		// fill the buffer with the received data
-		m_buffer.add( buffer, ret );
+		m_buffer.append(buffer);
 
 		slotReadLine();
 
@@ -417,7 +418,6 @@ void MSNSocket::slotDataReceived()
 	}
 
 	// Cleanup.
-	delete[] buffer;
 }
 
 void MSNSocket::slotReadLine()
@@ -434,7 +434,7 @@ void MSNSocket::slotReadLine()
 		}
 
 		int index = -1;
-		for ( uint x = 0; m_buffer.size() > x + 1; ++x )
+		for ( int x = 0; m_buffer.size() > x + 1; ++x )
 		{
 			if ( ( m_buffer[ x ] == '\r' ) && ( m_buffer[ x + 1 ] == '\n' ) )
 			{
@@ -447,7 +447,7 @@ void MSNSocket::slotReadLine()
 		{
 			QString command = QString::fromUtf8( m_buffer.take( index + 2 ), index );
 			command.replace( "\r\n", "" );
-			//kdDebug( 14141 ) << k_funcinfo << command << endl;
+			//kDebug( 14141 ) << command;
 
 			// Don't block the GUI while parsing data, only do a single line!
 			// (Done before parseLine() to prevent a potential crash)
@@ -459,18 +459,18 @@ void MSNSocket::slotReadLine()
 	}
 }
 
-void MSNSocket::readBlock( uint len )
+void MSNSocket::read( uint len )
 {
 	if ( m_waitBlockSize )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "Cannot wait for data block: still waiting for other block of size "
+		kWarning( 14140 ) << "Cannot wait for data block: still waiting for other block of size "
 			<< m_waitBlockSize << "! Data will not be returned." << endl;
 		return;
 	}
 
 	m_waitBlockSize = len;
 
-	//kdDebug( 14140 ) << k_funcinfo << "Preparing for block read of size " << len << endl;
+	//kDebug( 14140 ) << "Preparing for block read of size " << len;
 
 	// Try to return the data now, if available. Otherwise slotDataReady
 	// will do this whenever all data is there.
@@ -485,13 +485,13 @@ bool MSNSocket::pollReadBlock()
 	}
 	else if ( m_buffer.size() < m_waitBlockSize )
 	{
-		kdDebug( 14140 ) << k_funcinfo << "Waiting for data. Received: " << m_buffer.size() << ", required: " << m_waitBlockSize << endl;
+		kDebug( 14140 ) << "Waiting for data. Received: " << m_buffer.size() << ", required: " << m_waitBlockSize;
 		return true;
 	}
 
 	QByteArray block = m_buffer.take( m_waitBlockSize );
 
-	//kdDebug( 14140 ) << k_funcinfo << "Successfully read block of size " << m_waitBlockSize << endl;
+	//kDebug( 14140 ) << "Successfully read block of size " << m_waitBlockSize;
 
 	m_waitBlockSize = 0;
 	emit blockRead( block);
@@ -510,12 +510,12 @@ void MSNSocket::parseLine( const QString &str )
 	// In some rare cases, like the 'NLN' / 'FLN' commands no id at all
 	// is sent. Here it's actually a real parameter...
 	if ( !isNum )
-		data = str.section( ' ', 1, 1 ) + " " + data;
+		data = str.section( ' ', 1, 1 ) + ' ' + data;
 
 	//if ( isNum && id )
 	//	m_lastId = id;
 
-	//kdDebug( 14140 ) << k_funcinfo << "Parsing command " << cmd << " (ID " << id << "): '" << data << "'" << endl;
+	//kDebug( 14140 ) << "Parsing command " << cmd << " (ID " << id << "): '" << data << "'";
 
 	data.replace( "\r\n", "" );
 	bool isError;
@@ -528,9 +528,9 @@ void MSNSocket::parseLine( const QString &str )
 
 void MSNSocket::handleError( uint code, uint /* id */ )
 {
-	kdDebug(14140) << k_funcinfo << endl;
+	kDebug(14140) ;
 	QString msg;
-	ErrorType type = ErrorServerError;
+
 	switch ( code )
 	{
 /*
@@ -543,7 +543,7 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 		msg = i18n ( "Fully Qualified domain name missing.\n" );
 		break;
 	case 207:
-		msg = i18n ( "You are already logged in!\n" );
+		msg = i18n ( "You are already logged in.\n" );
 		break;
 	case 208:
 		msg = i18n ( "You specified an invalid username.\nPlease correct it, and try to reconnect.\n");
@@ -564,21 +564,21 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 		msg = i18n ( "You are not logged in.\n" );
 		break;
 */
+    case 402:
+    case 403:
+        msg = i18n ( "Error accessing contact list. Please try again later." );
+        break;
 	case 500:
 		msg = i18n ( "An internal server error occurred. Please try again later." );
-		type = MSNSocket::ErrorCannotConnect;
 		break;
 	case 502:
 		msg = i18n ( "It is no longer possible to perform this operation. The MSN server does not allow it anymore." );
-		type = MSNSocket::ErrorServerError;
 		break;
 	case 600:
 	case 910:
 	case 912:
-	case 921:
 	case 922:
 		msg = i18n ( "The MSN server is busy. Please try again later." );
-		type = MSNSocket::ErrorConnectionError;
 		break;
 	case 601:
 	case 604:
@@ -588,19 +588,18 @@ void MSNSocket::handleError( uint code, uint /* id */ )
 	case 916:
 	case 917:
 		msg = i18n ( "The server is not available at the moment. Please try again later." );
-		type = MSNSocket::ErrorCannotConnect;
 		break;
-	// Server error
 	default:
 		// FIXME: if the error causes a disconnect, it will crash, but we can't disconnect every time
 		msg = i18n( "Unhandled MSN error code %1 \n"
-			"Please fill a bug report with a detailed description and if possible the last console debug output." ).arg( code );
+			"Please file a bug report with a detailed description and, if possible, the last console debug output.", code );
 			// "See http://www.hypothetic.org/docs/msn/basics.php for a description of all error codes."
 		break;
 	}
 
 	if ( !msg.isEmpty() )
-		emit errorMessage( type, msg );
+		//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Error, msg, i18n( "MSN Plugin" ) );
+		emit errorMessage( ErrorNormal, msg );
 
 	return;
 }
@@ -609,38 +608,28 @@ int MSNSocket::sendCommand( const QString &cmd, const QString &args, bool addId,
 {
 	if ( !m_socket )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "m_socket == NULL!" << endl;
+		kWarning( 14140 ) << "m_socket == NULL!";
 		return -1;
 	}
 
-	QCString data = cmd.utf8();
+	QByteArray data = cmd.toUtf8();
 	if ( addId )
-		data += " " + QString::number( m_id ).utf8();
+		data += ' ' + QString::number( m_id ).toUtf8();
 
 	if ( !args.isEmpty() )
-		data += " " + args.utf8();
+		data += ' ' + args.toUtf8();
 
 	// Add length in bytes, not characters
 	if ( !body.isEmpty() )
-		data += " " + QString::number( body.size() - (binary ? 0 : 1 ) ).utf8();
+		data += ' ' + QString::number( binary ? body.size() : qstrlen(body) ).toUtf8();
 
 	data += "\r\n";
 
-
 	// the command will be sent in slotReadyWrite
-	QByteArray bytes;
-	const uint length = data.length();
-	bytes.duplicate(data.data(), length);
-	if(!body.isEmpty())
-	{
-		uint l = body.size() - (binary ? 0 : 1);
-		bytes.resize(length + l);
-		for(uint i=0; i < l; i++)
-			bytes[length + i] = body[i];
-	}
+	data += body;
 
 	// Add the request to the queue.
-	m_sendQueue.append(bytes);
+	m_sendQueue.append(data);
 	m_socket->enableWrite(true);
 
 	if ( addId )
@@ -657,7 +646,7 @@ void MSNSocket::slotReadyWrite()
 	if ( !m_sendQueue.isEmpty() )
 	{
 		// If the command queue is not empty, retrieve the first command.
-		QValueList<QByteArray>::Iterator it = m_sendQueue.begin();
+		QList<QByteArray>::Iterator it = m_sendQueue.begin();
 
 		if(m_useHttp)
 		{
@@ -693,22 +682,23 @@ void MSNSocket::slotReadyWrite()
 
 				uint length = s.length();
 				// Create the web request bytes.
-				QByteArray bytes(length + (*it).size());
+				QByteArray bytes;
+				bytes.reserve(length + (*it).size());
 
 				// Copy the request headers into the request bytes.
 				for(uint i=0; i < length; i++)
-					bytes[i] = s.ascii()[i];
+					bytes[i] = s.toAscii()[i];
 				// Copy the request body into the request bytes.
-				for(uint i=0; i < (*it).size(); i++)
+				for(int i=0; i < (*it).size(); i++)
 					bytes[length + i] = (*it)[i];
 
-				kdDebug( 14141 ) << k_funcinfo << "Sending http command: " << QString(*it).stripWhiteSpace() << endl;
+				kDebug( 14141 ) << "Sending http command: " << QString(*it).trimmed();
 
 				// Write the request bytes to the socket.
-				m_socket->writeBlock(bytes.data(), bytes.size());
+				m_socket->write(bytes.data(), bytes.size());
 
 				// Remove the request from the request queue.
-				m_sendQueue.remove(it);
+				m_sendQueue.erase(it);
 
 				if(m_sendQueue.isEmpty())
 				{
@@ -722,9 +712,15 @@ void MSNSocket::slotReadyWrite()
 		else
 		{
 			// Otherwise, send the command normally.
-			kdDebug( 14141 ) << k_funcinfo << "Sending command: " << QString( *it ).stripWhiteSpace() << endl;
-			m_socket->writeBlock( *it, ( *it ).size() );
-			m_sendQueue.remove( it );
+
+			// Simple check to avoid dumping the binary data from the icons and emoticons to kdDebug:
+			// When sending an MSN-P2P packet, strip off anything after the P2P header.
+			QString debugData = QString( *it ).trimmed().replace(
+				QRegExp( "(P2P-Dest:.[a-zA-Z@.]*).*" ), "\\1\n\n(Stripped binary data)" );
+			kDebug( 14141 ) << "Sending command: " << debugData;
+
+			m_socket->write( *it, ( *it ).size() );
+			m_sendQueue.erase( it );
 
 			// If the queue is empty agalin stop waiting for readyWrite signals
 			// because of the CPU usage
@@ -746,7 +742,7 @@ void MSNSocket::slotReadyWrite()
 
 QString MSNSocket::escape( const QString &str )
 {
-	//return ( KURL::encode_string( str, 106 ) );
+	//return ( KUrl::encode_string( str, 106 ) );
 	//It's not needed to encode everything. The official msn client only encode spaces and %
 	//If we encode more, the size can be longer than excepted.
 
@@ -782,7 +778,7 @@ QString MSNSocket::escape( const QString &str )
 
 QString MSNSocket::unescape( const QString &str )
 {
-	QString str2 = KURL::decode_string( str, 106 );
+        QString str2 = QUrl::fromPercentEncoding( str.toUtf8() );
 	//remove msn+ colors code
 	str2 = str2.replace( QRegExp("[\\x1-\\x8]"), "" ); // old msn+ colors
 	// added by kaoul <erwin.kwolek at gmail.com>
@@ -801,10 +797,11 @@ void MSNSocket::slotConnectionSuccess()
 		m_pending  = false;
 		m_bCanPoll = false;
 		// If we are connected, start the timer.
-		m_timer->start(2000, false);
+		m_timer->setSingleShot(false);
+		m_timer->start(2000);
 	}
 
-	//kdDebug( 14140 ) << k_funcinfo << endl;
+	//kDebug( 14140 ) ;
 	doneConnect();
 }
 
@@ -815,11 +812,11 @@ void MSNSocket::slotHostFound()
 
 void MSNSocket::slotSocketClosed()
 {
-    kdDebug( 14140 ) << k_funcinfo << "Socket closed. " << endl;
+    kDebug( 14140 ) << "Socket closed. ";
 
 	if ( !m_socket ||  m_onlineStatus == Disconnected )
 	{
-		kdDebug( 14140 ) << k_funcinfo << "Socket already deleted or already disconnected" << endl;
+		kDebug( 14140 ) << "Socket already deleted or already disconnected";
 		return;
 	}
 
@@ -841,8 +838,8 @@ void MSNSocket::slotHttpPoll()
 	}
 
 	// Create the http request headers.
-	const QCString headers = makeHttpRequestString(m_gwip, "Action=poll&SessionID=" + m_sessionId, 0).utf8();
-	m_socket->writeBlock(headers, headers.length());
+	const QByteArray headers = makeHttpRequestString(m_gwip, "Action=poll&SessionID=" + m_sessionId, 0).toUtf8();
+	m_socket->write(headers, headers.length());
 	// Wait for the response.
 	m_pending = true;
 	m_socket->enableWrite(true);
@@ -852,18 +849,18 @@ void MSNSocket::slotHttpPoll()
 // FIXME: Why is this here if it's only used for file transfer? - Martijn
 void MSNSocket::bytesReceived( const QByteArray & /* data */ )
 {
-	kdWarning( 14140 ) << k_funcinfo << "Unknown bytes were received" << endl;
+	kWarning( 14140 ) << "Unknown bytes were received";
 }
 
 void MSNSocket::sendBytes( const QByteArray &data )
 {
 	if ( !m_socket )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "Not yet connected" << endl;
+		kWarning( 14140 ) << "Not yet connected";
 		return;
 	}
 
-	m_socket->writeBlock( data, data.size() );
+	m_socket->write( data, data.size() );
 	m_socket->enableWrite( true );
 }
 
@@ -873,13 +870,13 @@ bool MSNSocket::setUseHttpMethod( bool useHttp )
 		return true;
 
 	if( useHttp ) {
-		QString s = QString( this->className() ).lower();
+		QString s = QString( this->metaObject()->className() ).toLower();
 		if( s == "msnnotifysocket" )
 			m_type = "NS";
 		else if( s == "msnswitchboardsocket" )
 			m_type = "SB";
 		else
-			m_type = QString::null;
+			m_type.clear();
 
 		if( m_type.isNull() )
 			return false;
@@ -908,7 +905,7 @@ bool MSNSocket::accept( KServerSocket *server )
 {
 	if ( m_socket )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "Socket already exists!" << endl;
+		kWarning( 14140 ) << "Socket already exists!";
 		return false;
 	}
 
@@ -916,11 +913,11 @@ bool MSNSocket::accept( KServerSocket *server )
 
 	if ( !m_socket )
 	{
-//		kdWarning( 14140 ) << k_funcinfo << "Socket not created.  Error nb" << server->error() << " : " << server->errorString() << endl;
+//		kWarning( 14140 ) << "Socket not created.  Error nb" << server->error() << " : " << server->errorString();
 		return false;
 	}
 
-	kdDebug( 14140 ) << k_funcinfo << "incoming connection accepted" << endl;
+	kDebug( 14140 ) << "incoming connection accepted";
 
 	setOnlineStatus( Connecting );
 
@@ -944,55 +941,40 @@ bool MSNSocket::accept( KServerSocket *server )
 QString MSNSocket::getLocalIP()
 {
 	if ( !m_socket )
-		return QString::null;
+		return QString();
 
 	const KSocketAddress address = m_socket->localAddress();
 
 	QString ip = address.nodeName();
 
-	kdDebug( 14140 ) << k_funcinfo << "IP: " << ip  <<endl;
+	kDebug( 14140 ) << "IP: " << ip;
 	//delete address;
 	return ip;
 }
 
 MSNSocket::Buffer::Buffer( unsigned int sz )
-: QByteArray( sz )
+: QByteArray( )
 {
+	reserve( sz );
 }
 
 MSNSocket::Buffer::~Buffer()
 {
 }
 
-void MSNSocket::Buffer::add( char *str, unsigned int sz )
-{
-	char *b = new char[ size() + sz ];
-	for ( uint f = 0; f < size(); f++ )
-		b[ f ] = data()[ f ];
-	for ( uint f = 0; f < sz; f++ )
-		b[ size() + f ] = str[ f ];
-
-	duplicate( b, size() + sz );
-	delete[] b;
-}
-
-QByteArray MSNSocket::Buffer::take( unsigned blockSize )
+QByteArray MSNSocket::Buffer::take( int blockSize )
 {
 	if ( size() < blockSize )
 	{
-		kdWarning( 14140 ) << k_funcinfo << "Buffer size " << size() << " < asked size " << blockSize << "!" << endl;
+		kWarning( 14140 ) << "Buffer size " << size() << " < asked size " << blockSize << '!';
 		return QByteArray();
 	}
 
-	QByteArray rep( blockSize );
-	for( uint i = 0; i < blockSize; i++ )
-		rep[ i ] = data()[ i ];
+	QByteArray rep = left(blockSize);
 
-	char *str = new char[ size() - blockSize ];
-	for ( uint i = 0; i < size() - blockSize; i++ )
-		str[ i ] = data()[ blockSize + i ];
-	duplicate( str, size() - blockSize );
-	delete[] str;
+	QByteArray newThis = right( size() - blockSize );
+	QByteArray *that = this;
+	*that = newThis;
 
 	return rep;
 }
@@ -1021,19 +1003,19 @@ MSNSocket::WebResponse::WebResponse(const QByteArray& bytes)
 
 	int     headerEnd;
   	QString header;
-	QString data(QCString(bytes, bytes.size() + 1));
+	QString data(QByteArray(bytes, bytes.size() + 1));
 
 	// Parse the HTTP status header
 	QRegExp re("HTTP/\\d\\.\\d (\\d+) ([^\r\n]+)");
-	headerEnd  = data.find("\r\n");
+	headerEnd  = data.indexOf("\r\n");
 	header     = data.left( (headerEnd == -1) ? 20 : headerEnd );
 
-	re.search(header);
+	re.indexIn(header);
 	m_statusCode = re.cap(1).toInt();
 	m_statusDescription = re.cap(2);
 
 	// Remove the web response status header.
-	data = data.mid(headerEnd + 2, (data.find("\r\n\r\n") + 2) - (headerEnd + 2));
+	data = data.mid(headerEnd + 2, (data.indexOf("\r\n\r\n") + 2) - (headerEnd + 2));
 	// Create a MimeMessage, removing the HTTP status header
 	m_headers = new MimeMessage(data);
 
@@ -1049,11 +1031,13 @@ MSNSocket::WebResponse::WebResponse(const QByteArray& bytes)
 			// copy the web response content bytes.
 			int offset = bytes.size() - length;
 
-			QByteArray content(length);
+			QByteArray content;
+			content.reserve( length );
 			for(int i=0; i < length; i++)
 				content[i] = bytes[offset + i];
 			// Create the web response stream from the response content bytes.
-			m_stream = new QDataStream(content, IO_ReadOnly);
+            m_stream = new QDataStream( content );
+			m_stream->setVersion(QDataStream::Qt_3_3);
 		}
 	}
 }
